@@ -20,7 +20,7 @@ def _read_hdf5(filepath, branches, load_range=None):
     return ak.Array(outputs)
 
 
-def _read_root(filepath, branches, load_range=None, treename=None):
+def _read_root(filepath, branches, load_range=None, treename=None, branch_magic=None):
     import uproot
     with uproot.open(filepath) as f:
         if treename is None:
@@ -30,14 +30,27 @@ def _read_root(filepath, branches, load_range=None, treename=None):
             else:
                 raise RuntimeError(
                     'Need to specify `treename` as more than one trees are found in file %s: %s' %
-                    (filepath, str(branches)))
+                    (filepath, str(treenames)))
         tree = f[treename]
         if load_range is not None:
             start = math.trunc(load_range[0] * tree.num_entries)
             stop = max(start + 1, math.trunc(load_range[1] * tree.num_entries))
         else:
             start, stop = None, None
-        outputs = tree.arrays(filter_name=branches, entry_start=start, entry_stop=stop)
+        if branch_magic is not None:
+            branch_dict = {}
+            for name in branches:
+                decoded_name = name
+                for src, tgt in branch_magic.items():
+                    if src in decoded_name:
+                        decoded_name = decoded_name.replace(src, tgt)
+                branch_dict[name] = decoded_name
+            outputs = tree.arrays(filter_name=list(branch_dict.values()), entry_start=start, entry_stop=stop)
+            for name, decoded_name in branch_dict.items():
+                if name != decoded_name:
+                    outputs[name] = outputs[decoded_name]
+        else:
+            outputs = tree.arrays(filter_name=branches, entry_start=start, entry_stop=stop)
     return outputs
 
 
@@ -77,7 +90,9 @@ def _read_files(filelist, branches, load_range=None, show_progressbar=False, **k
             if ext == '.h5':
                 a = _read_hdf5(filepath, branches, load_range=load_range)
             elif ext == '.root':
-                a = _read_root(filepath, branches, load_range=load_range, treename=kwargs.get('treename', None))
+                a = _read_root(filepath, branches, load_range=load_range,
+                               treename=kwargs.get('treename', None),
+                               branch_magic=kwargs.get('branch_magic', None))
             elif ext == '.awkd':
                 a = _read_awkd(filepath, branches, load_range=load_range)
             elif ext == '.parquet':
